==> snf_3.3.0_webrelease.tar.gz: snf_3.3.0_webrelease/src/snfdc/rwgauss.r <==
      subroutine rgausscoord(name,natoms,co,ilab)
*-------------------------------------------------------------------
c  read in coordinates from Gaussian input file name
c
c  written by C. Herrmann, Uni Jena, 05/2005
*-------------------------------------------------------------------
      implicit none
c
      integer gunit,mxitem,lrow,nempty,natoms,i,j
      integer ist,end,ilab(*),find_nucl_charge
      parameter(mxitem=10)
      include 'fconstants.h'
      character(len=132) row,item(mxitem)
      character(len=2) el(100)
      real*8 co(3,100),string2real
      character*255 name
c
      gunit = 12
      nempty = 0
c
      open(gunit,file=name,status='unknown')
1     read(gunit,'(a132)',end=2) row
      call llen(row,lrow)
      if(row(1:10).eq.'          ') nempty = nempty +1
      if(nempty.eq.2) then
      i=1
      read(gunit,'(a132)',end=2) row
3     read(gunit,'(a132)',end=2) row
      if(row(1:10).ne.'          ') then
        read(row,*) el(i), co(1,i), co(2,i), co(3,i)
        do j=1,3
           co(j,i) =  co(j,i)*(1/bohr2ang)
        end do
        ilab(i)=find_nucl_charge(el(i))
        i=i+1
        goto 3
      end if
      end if
      goto 1
      close(gunit)
2     continue
      natoms = i-1

      end subroutine
c*******************************************************
      subroutine wgauss(tdr,natoms,ic,co)
*
*-------------------------------------------------------------------
*
*  generates Gaussian-input file 'force.com' on slaves
*
*  link 0 commands, route section, title section,
*  and molecule specification are read from 'gaussian.com'
*  as provided by the user.
*
*  written by C.Herrmann, Universitaet Bonn, 10/2004
*
*-------------------------------------------------------------------
*
      implicit none
c
      include 'fconstants.h'
      integer gunit,aunit,jstepa,natoms
      integer ic(natoms),ltd,i,j
      real*8 co(3,natoms)
      character*(*) tdr
      character*80 row(5)
      character*2 find_element
      external find_element
      character*255 fname, aname, element(natoms)
      parameter(gunit=13,aunit=14)
c
      call llen(tdr,ltd)
      aname=tdr(1:ltd)//'/gaussian.com'
      fname=tdr(1:ltd)//'/force.com'
c
      open(aunit,file=aname,status='unknown')
      read(aunit,'(a)') (row(i),i=1,5)
      close(aunit)
c
      open(unit=gunit,file=fname,status='unknown')
      write(gunit,'(a)') (row(i),i=1,5)
      do i=1,natoms
        write(gunit,10) find_element(ic(i)), (co(j,i)*bohr2ang,j=1,3)
      end do
10    format(a4,2x,3F18.12)
      write(gunit,*) ''
      close(gunit)
c
      end subroutine
c*******************************************************
      subroutine rgauss(name,natoms)
*-------------------------------------------------------------------
*  read in number of atoms from file name
c
c  written by C. Herrmann, Uni Jena, 05/2005
*-------------------------------------------------------------------
      implicit none
c
      integer gunit,mxitem,lrow,nempty,natoms,i,j
      integer ist,end
      parameter(mxitem=10)
      include 'fconstants.h'
      character(len=132) row,item(mxitem)
      character*255 name
c
      gunit = 11
      nempty = 0
c
      open(gunit,file=name,status='unknown')
1     read(gunit,'(a132)',end=2) row
      call llen(row,lrow)
      if(row(1:10).eq.'          ') nempty = nempty +1
      if(nempty.eq.2) then
      i=1
      read(gunit,'(a132)',end=2) row
3     read(gunit,'(a132)',end=2) row
      if(row(1:10).ne.'          ') then
        i=i+1
        goto 3
      end if
      end if
      goto 1
      close(gunit)
2     continue
      natoms = i-1

      end subroutine
c*******************************************************
c
      subroutine wgausspol(tdr,fname,iosl)
*
*-------------------------------------------------------------------
*
*  generates Gaussian single-point input file name on slaves
*  for calculation of polarizabilities
*
*  written by C.Herrmann, University of Jena, 06/2005
*
*-------------------------------------------------------------------
*
      implicit none
c
      include 'param.h'
      integer gunit,aunit,ltd,i,j,ibefore,lf
      integer iend,k,maxrow,iafter,info
      parameter(gunit=18,aunit=19,maxrow=100)
      character*(*) tdr,fname
      character(len=132) row(maxrow),item(mxitem),scratch
      character*2 find_element
      external find_element
      character*255 aname,fnamefull
      logical valbohr
      integer lrow(maxrow),iosl,ii,ij
      logical static
      include 'fconstants.h'
c
      call llen(tdr,ltd)
      call llen(fname,lf)
      fnamefull=tdr(1:ltd)//'/'//fname(1:lf)
      aname=tdr(1:ltd)//'/force.com'
      call llen(fnamefull,lf)
      write(iosl,*) 'ANAME = ',aname
      write(iosl,*) 'FNAMEFULL = ',fnamefull(1:lf)
      call flush(iosl)
c
      static=.false.
      if(ipol.eq.1.and.omeg(1).eq.0.0d0) static=.true.
c
      i = 1
      open(aunit,file=aname,status='unknown')
10    read(aunit,'(a)',end = 35) row(i)
      call llen(row(i),lrow(i))
      ii=index(row(i),'Force')
      ij=index(row(i),'#')
      if(ii.ne.0) then
       if(static) row(i)=row(i)(ij+1:ii-1)//' #p Polar '
     * //row(i)(ii+5:lrow(i))
       if(.not.static) 
     * row(i)=row(i)(ij+1:ii-1)//' #p Polar CPHF=RdFreq'
     * //row(i)(ii+5:lrow(i))
       call llen(row(i),lrow(i))
      end if
      i=i+1
      goto 10
35    continue
      iend=i-1
      close(aunit)
c
      open(unit=gunit,file=fnamefull(1:lf),
     *status='unknown')
      do i = 1,iend
        write(gunit,'(a)') row(i)(1:lrow(i))
      end do
      if(.not.static) write(gunit,'(10f16.8)') (omeg(j),j=1,ipol)
      write(gunit,'(a)')
      close(gunit)
c
      end subroutine wgausspol

==> snf-4.0.0_webrelease.tar.gz: snf-4.0.0_webrelease/src/snfdc/rwgauss.r <==
      subroutine rgausscoord(name,natoms,co,ilab)
*-------------------------------------------------------------------
c  read in coordinates from Gaussian input file name
c
c  written by C. Herrmann, Uni Jena, 05/2005
*-------------------------------------------------------------------
      implicit none
c
      integer gunit,mxitem,lrow,nempty,natoms,i,j
      integer ist,end,ilab(*),find_nucl_charge
      parameter(mxitem=10)
      include 'fconstants.h'
      character*(132) row,item(mxitem)
      character*(2) el(natoms)
      real*8 co(3,natoms),string2real
      character*(*) name
c
      gunit = 12
      nempty = 0
c
      open(gunit,file=name,status='unknown')
1     read(gunit,'(a132)',end=2) row
      if(row(1:10).eq.'          ') nempty = nempty +1
      if(nempty.eq.2) then
        i=1
        read(gunit,'(a132)',end=2) row
3       read(gunit,'(a132)',end=2) row
        if(row(1:10).ne.'          ') then
          read(row,*) el(i), co(1,i), co(2,i), co(3,i)
          do j=1,3
             co(j,i) =  co(j,i)*(1/bohr2ang)
          end do
          ilab(i)=find_nucl_charge(el(i))
          i=i+1
          goto 3
        else 
          goto 2
        end if
      end if
      goto 1
2     close(gunit)
      natoms = i-1

      end
c*******************************************************
      subroutine wgauss(tdr,natoms,ic,co,iosl)
*
*-------------------------------------------------------------------
*
*  generates Gaussian-input file 'force.com' on slaves
*
*  link 0 commands, route section, title section,
*  and molecule specification are read from 'gaussian.com'
*  as provided by the user.
*
*  written by C.Herrmann, Universitaet Bonn, 10/2004
*
*-------------------------------------------------------------------
*
      implicit none
c
      include 'fconstants.h'
      integer gunit,aunit,jstepa,natoms,nempty,iosl
      integer ic(natoms),ltd,i,j,ivor,inach,iend,mxrow
      parameter(mxrow=1000)
      real*8 co(3,natoms)
      character*(*) tdr
      character*80 row(mxrow)
      character*2 find_element
      external find_element
      character*255 fname, aname, element(natoms)
      parameter(gunit=13,aunit=14)
c
      call llen(tdr,ltd)
      aname=tdr(1:ltd)//'/gaussian.com'
      fname=tdr(1:ltd)//'/force.com'
      nempty=0
c
      open(aunit,file=aname,status='unknown')
      i=1
1     read(aunit,'(a)') row(i)
      if(row(i)(1:10).eq.'          ') nempty = nempty +1
      if(nempty.eq.2) then
        i=i+1
        read(aunit,'(a)') row(i)
        ivor=i
        inach=i+1
        do j=1,natoms
          read(aunit,'(a)') 
        end do
        i=i+1
        goto 2
      end if
      i=i+1
      goto 1
2     read(aunit,'(a)',end=3) row(i) 
      i=i+1
      goto 2
3     close(aunit)
      iend=i-1
c
      open(unit=gunit,file=fname,status='unknown')
      write(gunit,'(a)') (row(i),i=1,ivor)
      do i=1,natoms
        write(gunit,10) find_element(ic(i)), (co(j,i)*bohr2ang,j=1,3)
      end do
      write(gunit,'(a)') (row(i),i=inach,iend)
10    format(a4,2x,3F18.12)
      write(gunit,*) ''
      close(gunit)
c
      end
c*******************************************************
      subroutine rgauss(name,natoms)
*-------------------------------------------------------------------
*  read in number of atoms from file name
c
c  written by C. Herrmann, Uni Jena, 05/2005
*-------------------------------------------------------------------
      implicit none
c
      integer gunit,mxitem,lrow,nempty,natoms,i,j
      integer ist,end
      parameter(mxitem=10)
      include 'fconstants.h'
      character*(132) row,item(mxitem)
      character*(*) name
c
      gunit = 11
      nempty = 0
c
      open(gunit,file=name,status='unknown')
1     read(gunit,'(a132)',end=2) row
      call llen(row,lrow)
      if(row(1:10).eq.'          ') nempty = nempty +1
      if(nempty.eq.2) then
      i=1
      read(gunit,'(a132)',end=2) row
3     read(gunit,'(a132)',end=2) row
      if(row(1:10).ne.'          ') then
        i=i+1
        goto 3
      else
        goto 2
      end if
      end if
      goto 1
2     close(gunit)
      natoms = i-1

      end 
c*******************************************************
c
      subroutine wgausspol(tdr,aname,fname,iosl)
*
*-------------------------------------------------------------------
*
*  generates Gaussian single-point input file name on slaves
*  for calculation of polarizabilities
*
*  written by C.Herrmann, University of Jena, 06/2005
*
*-------------------------------------------------------------------
*
      implicit none
c
      include 'param.h'
      integer gunit,aunit,ltd,i,j,ibefore,lf
      integer iend,k,maxrow,iafter,info,laname
      parameter(gunit=18,aunit=19,maxrow=1000)
      character*(*) tdr,fname,aname
      character*(132) row(maxrow),item(mxitem),scratch
      character*2 find_element
      external find_element
      character*255 fnamefull,anamefull
      logical valbohr
      integer lrow(maxrow),iosl,ii,ij
      logical static
      include 'fconstants.h'
c
      call llen(tdr,ltd)
      call llen(fname,lf)
      call llen(aname,laname)
      fnamefull=tdr(1:ltd)//'/'//fname(1:lf)
      anamefull=tdr(1:ltd)//'/'//aname(1:laname)
      call llen(fnamefull,lf)
      call llen(anamefull,laname)
c
      static=.false.
      if(ipol.eq.1.and.omeg(1).eq.0.0d0) static=.true.
c
      i = 1
      open(aunit,file=anamefull(1:laname),status='unknown')
10    read(aunit,'(a)',end = 35) row(i)
      call llen(row(i),lrow(i))
      ii=index(row(i),'Force')
      ij=index(row(i),'#')
      if(ii.ne.0) then
       if(static) row(i)=row(i)(ij+1:ii-1)//' #p Polar '
     * //row(i)(ii+5:lrow(i))
       if(.not.static) 
     * row(i)=row(i)(ij+1:ii-1)//' #p Polar CPHF=RdFreq'
     * //row(i)(ii+5:lrow(i))
       call llen(row(i),lrow(i))
      end if
      i=i+1
      goto 10
35    continue
      iend=i-1
      close(aunit)
c
      open(unit=gunit,file=fnamefull(1:lf),
     *status='unknown')
      do i = 1,iend
        write(gunit,'(a)') row(i)(1:lrow(i))
      end do
      if(.not.static) write(gunit,'(10f16.8)') (omeg(j),j=1,ipol)
      write(gunit,'(a)')
      close(gunit)
c
      end
